Files
codex/prs/bolinfest/PR-1164.md
2025-09-02 15:17:45 -07:00

140 lines
5.2 KiB
Markdown

# PR #1164: fix(codex-rs): use codex-mini-latest as default
- URL: https://github.com/openai/codex/pull/1164
- Author: fouad-openai
- Created: 2025-05-29 22:38:22 UTC
- Updated: 2025-05-29 23:55:29 UTC
- Changes: +7/-7, Files changed: 4, Commits: 3
## Description
(No description.)
## Full Diff
```diff
diff --git a/codex-rs/README.md b/codex-rs/README.md
index a0e3f5846e..a26f5b6d1d 100644
--- a/codex-rs/README.md
+++ b/codex-rs/README.md
@@ -32,7 +32,7 @@ The `config.toml` file supports the following options:
The model that Codex should use.
```toml
-model = "o3" # overrides the default of "o4-mini"
+model = "o3" # overrides the default of "codex-mini-latest"
```
### model_provider
@@ -155,7 +155,7 @@ Users can specify config values at multiple levels. Order of precedence is as fo
1. custom command-line argument, e.g., `--model o3`
2. as part of a profile, where the `--profile` is specified via a CLI (or in the config file itself)
3. as an entry in `config.toml`, e.g., `model = "o3"`
-4. the default value that comes with Codex CLI (i.e., Codex CLI defaults to `o4-mini`)
+4. the default value that comes with Codex CLI (i.e., Codex CLI defaults to `codex-mini-latest`)
### sandbox_permissions
diff --git a/codex-rs/common/src/config_override.rs b/codex-rs/common/src/config_override.rs
index bd2c036940..610195d6d1 100644
--- a/codex-rs/common/src/config_override.rs
+++ b/codex-rs/common/src/config_override.rs
@@ -23,7 +23,7 @@ pub struct CliConfigOverrides {
/// parse as JSON, the raw string is used as a literal.
///
/// Examples:
- /// - `-c model="o4-mini"`
+ /// - `-c model="o3"`
/// - `-c 'sandbox_permissions=["disk-full-read-access"]'`
/// - `-c shell_environment_policy.inherit=all`
#[arg(
@@ -61,7 +61,7 @@ impl CliConfigOverrides {
// Attempt to parse as JSON. If that fails, treat it as a raw
// string. This allows convenient usage such as
- // `-c model=o4-mini` without the quotes.
+ // `-c model=o3` without the quotes.
let value: Value = match parse_toml_value(value_str) {
Ok(v) => v,
Err(_) => Value::String(value_str.to_string()),
diff --git a/codex-rs/core/src/flags.rs b/codex-rs/core/src/flags.rs
index e8cc973c99..c21ef67026 100644
--- a/codex-rs/core/src/flags.rs
+++ b/codex-rs/core/src/flags.rs
@@ -3,7 +3,7 @@ use std::time::Duration;
use env_flags::env_flags;
env_flags! {
- pub OPENAI_DEFAULT_MODEL: &str = "o4-mini";
+ pub OPENAI_DEFAULT_MODEL: &str = "codex-mini-latest";
pub OPENAI_API_BASE: &str = "https://api.openai.com/v1";
/// Fallback when the provider-specific key is not set.
diff --git a/codex-rs/core/src/protocol.rs b/codex-rs/core/src/protocol.rs
index 1b9871edd8..fc18f1d821 100644
--- a/codex-rs/core/src/protocol.rs
+++ b/codex-rs/core/src/protocol.rs
@@ -561,7 +561,7 @@ mod tests {
id: "1234".to_string(),
msg: EventMsg::SessionConfigured(SessionConfiguredEvent {
session_id,
- model: "o4-mini".to_string(),
+ model: "codex-mini-latest".to_string(),
history_log_id: 0,
history_entry_count: 0,
}),
@@ -569,7 +569,7 @@ mod tests {
let serialized = serde_json::to_string(&event).unwrap();
assert_eq!(
serialized,
- r#"{"id":"1234","msg":{"type":"session_configured","session_id":"67e55044-10b1-426f-9247-bb680e5fe0c8","model":"o4-mini","history_log_id":0,"history_entry_count":0}}"#
+ r#"{"id":"1234","msg":{"type":"session_configured","session_id":"67e55044-10b1-426f-9247-bb680e5fe0c8","model":"codex-mini-latest","history_log_id":0,"history_entry_count":0}}"#
);
}
}
```
## Review Comments
### codex-rs/common/src/config_override.rs
- Created: 2025-05-29 22:47:43 UTC | Link: https://github.com/openai/codex/pull/1164#discussion_r2114856819
```diff
@@ -23,7 +23,7 @@ pub struct CliConfigOverrides {
/// parse as JSON, the raw string is used as a literal.
///
/// Examples:
- /// - `-c model="o4-mini"`
+ /// - `-c model="codex-mini-latest"`
```
> This stay as-is because this is meant to demonstrate an override.
- Created: 2025-05-29 23:02:11 UTC | Link: https://github.com/openai/codex/pull/1164#discussion_r2114868563
```diff
@@ -23,7 +23,7 @@ pub struct CliConfigOverrides {
/// parse as JSON, the raw string is used as a literal.
///
/// Examples:
- /// - `-c model="o4-mini"`
+ /// - `-c model="codex-mini-latest"`
```
> I think it can be anything other than the default, which will now be `codex-mini-latest`, right?
### codex-rs/mcp-server/src/codex_tool_config.rs
- Created: 2025-05-29 22:48:37 UTC | Link: https://github.com/openai/codex/pull/1164#discussion_r2114857544
```diff
@@ -19,7 +19,7 @@ pub(crate) struct CodexToolCallParam {
/// The *initial user prompt* to start the Codex conversation.
pub prompt: String,
/// Optional override for the model name (e.g. "o3", "o4-mini")
```
> Again, I would use `o4-mini` as the example of an override.
@@ -19,7 +19,7 @@ pub(crate) struct CodexToolCallParam {
/// The *initial user prompt* to start the Codex conversation.
pub prompt: String,
- /// Optional override for the model name (e.g. "o3", "o4-mini")
+ /// Optional override for the model name (e.g. "o3", "codex-mini-latest")
```
> Again, I would use `o4-mini` as the example of an override.